# AUTOGENERATED BY NBDEV! DO NOT EDIT!

__all__ = ["index", "modules", "custom_doc_links", "git_url"]

index = {"gdown_unzip": "06_uwb.ipynb",
         "pose_dis": "06_uwb.ipynb",
         "waypoint": "06_uwb.ipynb",
         "camera_projection": "01_camera_projection.ipynb",
         "get_images_from_video": "02_video2picture.ipynb",
         "robot_model_loader": "03_robot_model.ipynb",
         "get_key": "04_get_ip.ipynb",
         "myip": "04_get_ip.ipynb",
         "whoami": "04_get_ip.ipynb",
         "get_xbee_address": "04_get_ip.ipynb",
         "get_xbee_address_boat": "04_get_ip.ipynb",
         "find_duckiepond_devices_yaml": "04_get_ip.ipynb",
         "dp_load_config": "04_get_ip.ipynb",
         "dp_get_devices": "04_get_ip.ipynb",
         "device_get_sensors": "04_get_ip.ipynb",
         "sensor_get_topic": "04_get_ip.ipynb",
         "ssh_ping_nano": "04_get_ip.ipynb",
         "ssh_ping_rpi": "04_get_ip.ipynb",
         "test_ssh_intranet": "04_get_ip.ipynb",
         "ssh_connection": "04_get_ip.ipynb",
         "test_ssh": "04_get_ip.ipynb",
         "ip_connection": "04_get_ip.ipynb",
         "test_ping": "04_get_ip.ipynb",
         "ssh_rostopic": "04_get_ip.ipynb",
         "test_rostopic": "04_get_ip.ipynb",
         "random_generate": "05_random_map.ipynb",
         "sub_random_generate": "05_random_map.ipynb",
         "draw_line": "05_random_map.ipynb",
         "dist": "07_tsp.ipynb",
         "distanceGenerate": "07_tsp.ipynb",
         "sortWaypoint": "07_tsp.ipynb",
         "solve_tsp_nearest_neighbor": "07_tsp.ipynb",
         "solve_tsp_held_karp": "07_tsp.ipynb",
         "ros_socket": "08_websocket_rosbridge.ipynb"}

modules = ["utils.py",
           "camera_projection.py",
           "video2picture.py",
           "robot_model.py",
           "get_ip.py",
           "random_map.py",
           "uwb.py",
           "tsp.py",
           "websocket_rosbridge.py"]

doc_url = "https://ARG-NCTU.github.io/arg_robotics_tools/"

git_url = "https://github.com/ARG-NCTU/arg_robotics_tools/tree/master/"

def custom_doc_links(name): return None
